# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictBool
from uuid import UUID
from immich.client.models.asset_stats_response_dto import AssetStatsResponseDto
from immich.client.models.asset_visibility import AssetVisibility
from immich.client.models.session_response_dto import SessionResponseDto
from immich.client.models.user_admin_create_dto import UserAdminCreateDto
from immich.client.models.user_admin_delete_dto import UserAdminDeleteDto
from immich.client.models.user_admin_response_dto import UserAdminResponseDto
from immich.client.models.user_admin_update_dto import UserAdminUpdateDto
from immich.client.models.user_preferences_response_dto import (
    UserPreferencesResponseDto,
)
from immich.client.models.user_preferences_update_dto import UserPreferencesUpdateDto

from immich.client.api_client import ApiClient, RequestSerialized
from immich.client.api_response import ApiResponse
from immich.client.rest import RESTResponseType


class UsersAdminApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    async def create_user_admin(
        self,
        user_admin_create_dto: UserAdminCreateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserAdminResponseDto:
        """Create a user

        Create a new user.

        :param user_admin_create_dto: (required)
        :type user_admin_create_dto: UserAdminCreateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_user_admin_serialize(
            user_admin_create_dto=user_admin_create_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "201": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def create_user_admin_with_http_info(
        self,
        user_admin_create_dto: UserAdminCreateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserAdminResponseDto]:
        """Create a user

        Create a new user.

        :param user_admin_create_dto: (required)
        :type user_admin_create_dto: UserAdminCreateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_user_admin_serialize(
            user_admin_create_dto=user_admin_create_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "201": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def create_user_admin_without_preload_content(
        self,
        user_admin_create_dto: UserAdminCreateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a user

        Create a new user.

        :param user_admin_create_dto: (required)
        :type user_admin_create_dto: UserAdminCreateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_user_admin_serialize(
            user_admin_create_dto=user_admin_create_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "201": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _create_user_admin_serialize(
        self,
        user_admin_create_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if user_admin_create_dto is not None:
            _body_params = user_admin_create_dto

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/admin/users",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def delete_user_admin(
        self,
        id: UUID,
        user_admin_delete_dto: UserAdminDeleteDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserAdminResponseDto:
        """Delete a user

        Delete a user.

        :param id: (required)
        :type id: UUID
        :param user_admin_delete_dto: (required)
        :type user_admin_delete_dto: UserAdminDeleteDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_user_admin_serialize(
            id=id,
            user_admin_delete_dto=user_admin_delete_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def delete_user_admin_with_http_info(
        self,
        id: UUID,
        user_admin_delete_dto: UserAdminDeleteDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserAdminResponseDto]:
        """Delete a user

        Delete a user.

        :param id: (required)
        :type id: UUID
        :param user_admin_delete_dto: (required)
        :type user_admin_delete_dto: UserAdminDeleteDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_user_admin_serialize(
            id=id,
            user_admin_delete_dto=user_admin_delete_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def delete_user_admin_without_preload_content(
        self,
        id: UUID,
        user_admin_delete_dto: UserAdminDeleteDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete a user

        Delete a user.

        :param id: (required)
        :type id: UUID
        :param user_admin_delete_dto: (required)
        :type user_admin_delete_dto: UserAdminDeleteDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_user_admin_serialize(
            id=id,
            user_admin_delete_dto=user_admin_delete_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _delete_user_admin_serialize(
        self,
        id,
        user_admin_delete_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if user_admin_delete_dto is not None:
            _body_params = user_admin_delete_dto

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="DELETE",
            resource_path="/admin/users/{id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def get_user_admin(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserAdminResponseDto:
        """Retrieve a user

        Retrieve  a specific user by their ID.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def get_user_admin_with_http_info(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserAdminResponseDto]:
        """Retrieve a user

        Retrieve  a specific user by their ID.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def get_user_admin_without_preload_content(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve a user

        Retrieve  a specific user by their ID.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_user_admin_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/admin/users/{id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def get_user_preferences_admin(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserPreferencesResponseDto:
        """Retrieve user preferences

        Retrieve the preferences of a specific user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_preferences_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserPreferencesResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def get_user_preferences_admin_with_http_info(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserPreferencesResponseDto]:
        """Retrieve user preferences

        Retrieve the preferences of a specific user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_preferences_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserPreferencesResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def get_user_preferences_admin_without_preload_content(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve user preferences

        Retrieve the preferences of a specific user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_preferences_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserPreferencesResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_user_preferences_admin_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/admin/users/{id}/preferences",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def get_user_sessions_admin(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[SessionResponseDto]:
        """Retrieve user sessions

        Retrieve all sessions for a specific user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_sessions_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[SessionResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def get_user_sessions_admin_with_http_info(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[SessionResponseDto]]:
        """Retrieve user sessions

        Retrieve all sessions for a specific user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_sessions_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[SessionResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def get_user_sessions_admin_without_preload_content(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve user sessions

        Retrieve all sessions for a specific user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_sessions_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[SessionResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_user_sessions_admin_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/admin/users/{id}/sessions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def get_user_statistics_admin(
        self,
        id: UUID,
        is_favorite: Optional[StrictBool] = None,
        is_trashed: Optional[StrictBool] = None,
        visibility: Optional[AssetVisibility] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AssetStatsResponseDto:
        """Retrieve user statistics

        Retrieve asset statistics for a specific user.

        :param id: (required)
        :type id: UUID
        :param is_favorite:
        :type is_favorite: bool
        :param is_trashed:
        :type is_trashed: bool
        :param visibility:
        :type visibility: AssetVisibility
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_statistics_admin_serialize(
            id=id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            visibility=visibility,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "AssetStatsResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def get_user_statistics_admin_with_http_info(
        self,
        id: UUID,
        is_favorite: Optional[StrictBool] = None,
        is_trashed: Optional[StrictBool] = None,
        visibility: Optional[AssetVisibility] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AssetStatsResponseDto]:
        """Retrieve user statistics

        Retrieve asset statistics for a specific user.

        :param id: (required)
        :type id: UUID
        :param is_favorite:
        :type is_favorite: bool
        :param is_trashed:
        :type is_trashed: bool
        :param visibility:
        :type visibility: AssetVisibility
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_statistics_admin_serialize(
            id=id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            visibility=visibility,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "AssetStatsResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def get_user_statistics_admin_without_preload_content(
        self,
        id: UUID,
        is_favorite: Optional[StrictBool] = None,
        is_trashed: Optional[StrictBool] = None,
        visibility: Optional[AssetVisibility] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve user statistics

        Retrieve asset statistics for a specific user.

        :param id: (required)
        :type id: UUID
        :param is_favorite:
        :type is_favorite: bool
        :param is_trashed:
        :type is_trashed: bool
        :param visibility:
        :type visibility: AssetVisibility
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_user_statistics_admin_serialize(
            id=id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            visibility=visibility,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "AssetStatsResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_user_statistics_admin_serialize(
        self,
        id,
        is_favorite,
        is_trashed,
        visibility,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        if is_favorite is not None:
            _query_params.append(("isFavorite", is_favorite))

        if is_trashed is not None:
            _query_params.append(("isTrashed", is_trashed))

        if visibility is not None:
            _query_params.append(("visibility", visibility.value))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/admin/users/{id}/statistics",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def restore_user_admin(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserAdminResponseDto:
        """Restore a deleted user

        Restore a previously deleted user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._restore_user_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def restore_user_admin_with_http_info(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserAdminResponseDto]:
        """Restore a deleted user

        Restore a previously deleted user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._restore_user_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def restore_user_admin_without_preload_content(
        self,
        id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Restore a deleted user

        Restore a previously deleted user.

        :param id: (required)
        :type id: UUID
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._restore_user_admin_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _restore_user_admin_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/admin/users/{id}/restore",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def search_users_admin(
        self,
        id: Optional[UUID] = None,
        with_deleted: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[UserAdminResponseDto]:
        """Search users

        Search for users.

        :param id:
        :type id: UUID
        :param with_deleted:
        :type with_deleted: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._search_users_admin_serialize(
            id=id,
            with_deleted=with_deleted,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[UserAdminResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def search_users_admin_with_http_info(
        self,
        id: Optional[UUID] = None,
        with_deleted: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[UserAdminResponseDto]]:
        """Search users

        Search for users.

        :param id:
        :type id: UUID
        :param with_deleted:
        :type with_deleted: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._search_users_admin_serialize(
            id=id,
            with_deleted=with_deleted,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[UserAdminResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def search_users_admin_without_preload_content(
        self,
        id: Optional[UUID] = None,
        with_deleted: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search users

        Search for users.

        :param id:
        :type id: UUID
        :param with_deleted:
        :type with_deleted: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._search_users_admin_serialize(
            id=id,
            with_deleted=with_deleted,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[UserAdminResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _search_users_admin_serialize(
        self,
        id,
        with_deleted,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if id is not None:
            _query_params.append(("id", id))

        if with_deleted is not None:
            _query_params.append(("withDeleted", with_deleted))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/admin/users",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def update_user_admin(
        self,
        id: UUID,
        user_admin_update_dto: UserAdminUpdateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserAdminResponseDto:
        """Update a user

        Update an existing user.

        :param id: (required)
        :type id: UUID
        :param user_admin_update_dto: (required)
        :type user_admin_update_dto: UserAdminUpdateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_user_admin_serialize(
            id=id,
            user_admin_update_dto=user_admin_update_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def update_user_admin_with_http_info(
        self,
        id: UUID,
        user_admin_update_dto: UserAdminUpdateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserAdminResponseDto]:
        """Update a user

        Update an existing user.

        :param id: (required)
        :type id: UUID
        :param user_admin_update_dto: (required)
        :type user_admin_update_dto: UserAdminUpdateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_user_admin_serialize(
            id=id,
            user_admin_update_dto=user_admin_update_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def update_user_admin_without_preload_content(
        self,
        id: UUID,
        user_admin_update_dto: UserAdminUpdateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update a user

        Update an existing user.

        :param id: (required)
        :type id: UUID
        :param user_admin_update_dto: (required)
        :type user_admin_update_dto: UserAdminUpdateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_user_admin_serialize(
            id=id,
            user_admin_update_dto=user_admin_update_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserAdminResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _update_user_admin_serialize(
        self,
        id,
        user_admin_update_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if user_admin_update_dto is not None:
            _body_params = user_admin_update_dto

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="PUT",
            resource_path="/admin/users/{id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def update_user_preferences_admin(
        self,
        id: UUID,
        user_preferences_update_dto: UserPreferencesUpdateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserPreferencesResponseDto:
        """Update user preferences

        Update the preferences of a specific user.

        :param id: (required)
        :type id: UUID
        :param user_preferences_update_dto: (required)
        :type user_preferences_update_dto: UserPreferencesUpdateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_user_preferences_admin_serialize(
            id=id,
            user_preferences_update_dto=user_preferences_update_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserPreferencesResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def update_user_preferences_admin_with_http_info(
        self,
        id: UUID,
        user_preferences_update_dto: UserPreferencesUpdateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserPreferencesResponseDto]:
        """Update user preferences

        Update the preferences of a specific user.

        :param id: (required)
        :type id: UUID
        :param user_preferences_update_dto: (required)
        :type user_preferences_update_dto: UserPreferencesUpdateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_user_preferences_admin_serialize(
            id=id,
            user_preferences_update_dto=user_preferences_update_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserPreferencesResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def update_user_preferences_admin_without_preload_content(
        self,
        id: UUID,
        user_preferences_update_dto: UserPreferencesUpdateDto,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update user preferences

        Update the preferences of a specific user.

        :param id: (required)
        :type id: UUID
        :param user_preferences_update_dto: (required)
        :type user_preferences_update_dto: UserPreferencesUpdateDto
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_user_preferences_admin_serialize(
            id=id,
            user_preferences_update_dto=user_preferences_update_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UserPreferencesResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _update_user_preferences_admin_serialize(
        self,
        id,
        user_preferences_update_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if user_preferences_update_dto is not None:
            _body_params = user_preferences_update_dto

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="PUT",
            resource_path="/admin/users/{id}/preferences",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class SharedLinkEditDto(BaseModel):
    """
    SharedLinkEditDto
    """  # noqa: E501

    allow_download: Optional[StrictBool] = Field(default=None, alias="allowDownload")
    allow_upload: Optional[StrictBool] = Field(default=None, alias="allowUpload")
    change_expiry_time: Optional[StrictBool] = Field(
        default=None,
        description="Few clients cannot send null to set the expiryTime to never. Setting this flag and not sending expiryAt is considered as null instead. Clients that can send null values can ignore this.",
        alias="changeExpiryTime",
    )
    description: Optional[StrictStr] = None
    expires_at: Optional[datetime] = Field(default=None, alias="expiresAt")
    password: Optional[StrictStr] = None
    show_metadata: Optional[StrictBool] = Field(default=None, alias="showMetadata")
    slug: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "allowDownload",
        "allowUpload",
        "changeExpiryTime",
        "description",
        "expiresAt",
        "password",
        "showMetadata",
        "slug",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SharedLinkEditDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        # set to None if expires_at (nullable) is None
        # and model_fields_set contains the field
        if self.expires_at is None and "expires_at" in self.model_fields_set:
            _dict["expiresAt"] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict["password"] = None

        # set to None if slug (nullable) is None
        # and model_fields_set contains the field
        if self.slug is None and "slug" in self.model_fields_set:
            _dict["slug"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SharedLinkEditDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "allowDownload": obj.get("allowDownload"),
                "allowUpload": obj.get("allowUpload"),
                "changeExpiryTime": obj.get("changeExpiryTime"),
                "description": obj.get("description"),
                "expiresAt": obj.get("expiresAt"),
                "password": obj.get("password"),
                "showMetadata": obj.get("showMetadata"),
                "slug": obj.get("slug"),
            }
        )
        return _obj



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from immich.client.models.asset_type_enum import AssetTypeEnum
from immich.client.models.asset_visibility import AssetVisibility
from typing import Set
from typing_extensions import Self


class SyncAssetV1(BaseModel):
    """
    SyncAssetV1
    """  # noqa: E501

    checksum: StrictStr
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    duration: Optional[StrictStr]
    file_created_at: Optional[datetime] = Field(alias="fileCreatedAt")
    file_modified_at: Optional[datetime] = Field(alias="fileModifiedAt")
    id: StrictStr
    is_favorite: StrictBool = Field(alias="isFavorite")
    library_id: Optional[StrictStr] = Field(alias="libraryId")
    live_photo_video_id: Optional[StrictStr] = Field(alias="livePhotoVideoId")
    local_date_time: Optional[datetime] = Field(alias="localDateTime")
    original_file_name: StrictStr = Field(alias="originalFileName")
    owner_id: StrictStr = Field(alias="ownerId")
    stack_id: Optional[StrictStr] = Field(alias="stackId")
    thumbhash: Optional[StrictStr]
    type: AssetTypeEnum
    visibility: AssetVisibility
    __properties: ClassVar[List[str]] = [
        "checksum",
        "deletedAt",
        "duration",
        "fileCreatedAt",
        "fileModifiedAt",
        "id",
        "isFavorite",
        "libraryId",
        "livePhotoVideoId",
        "localDateTime",
        "originalFileName",
        "ownerId",
        "stackId",
        "thumbhash",
        "type",
        "visibility",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SyncAssetV1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if deleted_at (nullable) is None
        # and model_fields_set contains the field
        if self.deleted_at is None and "deleted_at" in self.model_fields_set:
            _dict["deletedAt"] = None

        # set to None if duration (nullable) is None
        # and model_fields_set contains the field
        if self.duration is None and "duration" in self.model_fields_set:
            _dict["duration"] = None

        # set to None if file_created_at (nullable) is None
        # and model_fields_set contains the field
        if self.file_created_at is None and "file_created_at" in self.model_fields_set:
            _dict["fileCreatedAt"] = None

        # set to None if file_modified_at (nullable) is None
        # and model_fields_set contains the field
        if (
            self.file_modified_at is None
            and "file_modified_at" in self.model_fields_set
        ):
            _dict["fileModifiedAt"] = None

        # set to None if library_id (nullable) is None
        # and model_fields_set contains the field
        if self.library_id is None and "library_id" in self.model_fields_set:
            _dict["libraryId"] = None

        # set to None if live_photo_video_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.live_photo_video_id is None
            and "live_photo_video_id" in self.model_fields_set
        ):
            _dict["livePhotoVideoId"] = None

        # set to None if local_date_time (nullable) is None
        # and model_fields_set contains the field
        if self.local_date_time is None and "local_date_time" in self.model_fields_set:
            _dict["localDateTime"] = None

        # set to None if stack_id (nullable) is None
        # and model_fields_set contains the field
        if self.stack_id is None and "stack_id" in self.model_fields_set:
            _dict["stackId"] = None

        # set to None if thumbhash (nullable) is None
        # and model_fields_set contains the field
        if self.thumbhash is None and "thumbhash" in self.model_fields_set:
            _dict["thumbhash"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SyncAssetV1 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "checksum": obj.get("checksum"),
                "deletedAt": obj.get("deletedAt"),
                "duration": obj.get("duration"),
                "fileCreatedAt": obj.get("fileCreatedAt"),
                "fileModifiedAt": obj.get("fileModifiedAt"),
                "id": obj.get("id"),
                "isFavorite": obj.get("isFavorite"),
                "libraryId": obj.get("libraryId"),
                "livePhotoVideoId": obj.get("livePhotoVideoId"),
                "localDateTime": obj.get("localDateTime"),
                "originalFileName": obj.get("originalFileName"),
                "ownerId": obj.get("ownerId"),
                "stackId": obj.get("stackId"),
                "thumbhash": obj.get("thumbhash"),
                "type": obj.get("type"),
                "visibility": obj.get("visibility"),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from immich.client.models.api_key_create_dto import APIKeyCreateDto
from immich.client.models.api_key_create_response_dto import APIKeyCreateResponseDto
from immich.client.models.api_key_response_dto import APIKeyResponseDto
from immich.client.models.api_key_update_dto import APIKeyUpdateDto
from immich.client.models.activity_create_dto import ActivityCreateDto
from immich.client.models.activity_response_dto import ActivityResponseDto
from immich.client.models.activity_statistics_response_dto import (
    ActivityStatisticsResponseDto,
)
from immich.client.models.add_users_dto import AddUsersDto
from immich.client.models.admin_onboarding_update_dto import AdminOnboardingUpdateDto
from immich.client.models.album_response_dto import AlbumResponseDto
from immich.client.models.album_statistics_response_dto import (
    AlbumStatisticsResponseDto,
)
from immich.client.models.album_user_add_dto import AlbumUserAddDto
from immich.client.models.album_user_create_dto import AlbumUserCreateDto
from immich.client.models.album_user_response_dto import AlbumUserResponseDto
from immich.client.models.album_user_role import AlbumUserRole
from immich.client.models.albums_add_assets_dto import AlbumsAddAssetsDto
from immich.client.models.albums_add_assets_response_dto import (
    AlbumsAddAssetsResponseDto,
)
from immich.client.models.albums_response import AlbumsResponse
from immich.client.models.albums_update import AlbumsUpdate
from immich.client.models.asset_bulk_delete_dto import AssetBulkDeleteDto
from immich.client.models.asset_bulk_update_dto import AssetBulkUpdateDto
from immich.client.models.asset_bulk_upload_check_dto import AssetBulkUploadCheckDto
from immich.client.models.asset_bulk_upload_check_item import AssetBulkUploadCheckItem
from immich.client.models.asset_bulk_upload_check_response_dto import (
    AssetBulkUploadCheckResponseDto,
)
from immich.client.models.asset_bulk_upload_check_result import (
    AssetBulkUploadCheckResult,
)
from immich.client.models.asset_copy_dto import AssetCopyDto
from immich.client.models.asset_delta_sync_dto import AssetDeltaSyncDto
from immich.client.models.asset_delta_sync_response_dto import AssetDeltaSyncResponseDto
from immich.client.models.asset_face_create_dto import AssetFaceCreateDto
from immich.client.models.asset_face_delete_dto import AssetFaceDeleteDto
from immich.client.models.asset_face_response_dto import AssetFaceResponseDto
from immich.client.models.asset_face_update_dto import AssetFaceUpdateDto
from immich.client.models.asset_face_update_item import AssetFaceUpdateItem
from immich.client.models.asset_face_without_person_response_dto import (
    AssetFaceWithoutPersonResponseDto,
)
from immich.client.models.asset_full_sync_dto import AssetFullSyncDto
from immich.client.models.asset_ids_dto import AssetIdsDto
from immich.client.models.asset_ids_response_dto import AssetIdsResponseDto
from immich.client.models.asset_job_name import AssetJobName
from immich.client.models.asset_jobs_dto import AssetJobsDto
from immich.client.models.asset_media_response_dto import AssetMediaResponseDto
from immich.client.models.asset_media_size import AssetMediaSize
from immich.client.models.asset_media_status import AssetMediaStatus
from immich.client.models.asset_metadata_key import AssetMetadataKey
from immich.client.models.asset_metadata_response_dto import AssetMetadataResponseDto
from immich.client.models.asset_metadata_upsert_dto import AssetMetadataUpsertDto
from immich.client.models.asset_metadata_upsert_item_dto import (
    AssetMetadataUpsertItemDto,
)
from immich.client.models.asset_ocr_response_dto import AssetOcrResponseDto
from immich.client.models.asset_order import AssetOrder
from immich.client.models.asset_response_dto import AssetResponseDto
from immich.client.models.asset_stack_response_dto import AssetStackResponseDto
from immich.client.models.asset_stats_response_dto import AssetStatsResponseDto
from immich.client.models.asset_type_enum import AssetTypeEnum
from immich.client.models.asset_visibility import AssetVisibility
from immich.client.models.audio_codec import AudioCodec
from immich.client.models.auth_status_response_dto import AuthStatusResponseDto
from immich.client.models.avatar_update import AvatarUpdate
from immich.client.models.bulk_id_error_reason import BulkIdErrorReason
from immich.client.models.bulk_id_response_dto import BulkIdResponseDto
from immich.client.models.bulk_ids_dto import BulkIdsDto
from immich.client.models.clip_config import CLIPConfig
from immich.client.models.cq_mode import CQMode
from immich.client.models.cast_response import CastResponse
from immich.client.models.cast_update import CastUpdate
from immich.client.models.change_password_dto import ChangePasswordDto
from immich.client.models.check_existing_assets_dto import CheckExistingAssetsDto
from immich.client.models.check_existing_assets_response_dto import (
    CheckExistingAssetsResponseDto,
)
from immich.client.models.colorspace import Colorspace
from immich.client.models.contributor_count_response_dto import (
    ContributorCountResponseDto,
)
from immich.client.models.create_album_dto import CreateAlbumDto
from immich.client.models.create_library_dto import CreateLibraryDto
from immich.client.models.create_profile_image_response_dto import (
    CreateProfileImageResponseDto,
)
from immich.client.models.database_backup_config import DatabaseBackupConfig
from immich.client.models.download_archive_info import DownloadArchiveInfo
from immich.client.models.download_info_dto import DownloadInfoDto
from immich.client.models.download_response import DownloadResponse
from immich.client.models.download_response_dto import DownloadResponseDto
from immich.client.models.download_update import DownloadUpdate
from immich.client.models.duplicate_detection_config import DuplicateDetectionConfig
from immich.client.models.duplicate_response_dto import DuplicateResponseDto
from immich.client.models.email_notifications_response import EmailNotificationsResponse
from immich.client.models.email_notifications_update import EmailNotificationsUpdate
from immich.client.models.exif_response_dto import ExifResponseDto
from immich.client.models.face_dto import FaceDto
from immich.client.models.facial_recognition_config import FacialRecognitionConfig
from immich.client.models.folders_response import FoldersResponse
from immich.client.models.folders_update import FoldersUpdate
from immich.client.models.image_format import ImageFormat
from immich.client.models.job_create_dto import JobCreateDto
from immich.client.models.job_name import JobName
from immich.client.models.job_settings_dto import JobSettingsDto
from immich.client.models.library_response_dto import LibraryResponseDto
from immich.client.models.library_stats_response_dto import LibraryStatsResponseDto
from immich.client.models.license_key_dto import LicenseKeyDto
from immich.client.models.license_response_dto import LicenseResponseDto
from immich.client.models.log_level import LogLevel
from immich.client.models.login_credential_dto import LoginCredentialDto
from immich.client.models.login_response_dto import LoginResponseDto
from immich.client.models.logout_response_dto import LogoutResponseDto
from immich.client.models.machine_learning_availability_checks_dto import (
    MachineLearningAvailabilityChecksDto,
)
from immich.client.models.maintenance_action import MaintenanceAction
from immich.client.models.maintenance_auth_dto import MaintenanceAuthDto
from immich.client.models.maintenance_login_dto import MaintenanceLoginDto
from immich.client.models.manual_job_name import ManualJobName
from immich.client.models.map_marker_response_dto import MapMarkerResponseDto
from immich.client.models.map_reverse_geocode_response_dto import (
    MapReverseGeocodeResponseDto,
)
from immich.client.models.memories_response import MemoriesResponse
from immich.client.models.memories_update import MemoriesUpdate
from immich.client.models.memory_create_dto import MemoryCreateDto
from immich.client.models.memory_response_dto import MemoryResponseDto
from immich.client.models.memory_search_order import MemorySearchOrder
from immich.client.models.memory_statistics_response_dto import (
    MemoryStatisticsResponseDto,
)
from immich.client.models.memory_type import MemoryType
from immich.client.models.memory_update_dto import MemoryUpdateDto
from immich.client.models.merge_person_dto import MergePersonDto
from immich.client.models.metadata_search_dto import MetadataSearchDto
from immich.client.models.notification_create_dto import NotificationCreateDto
from immich.client.models.notification_delete_all_dto import NotificationDeleteAllDto
from immich.client.models.notification_dto import NotificationDto
from immich.client.models.notification_level import NotificationLevel
from immich.client.models.notification_type import NotificationType
from immich.client.models.notification_update_all_dto import NotificationUpdateAllDto
from immich.client.models.notification_update_dto import NotificationUpdateDto
from immich.client.models.o_auth_authorize_response_dto import OAuthAuthorizeResponseDto
from immich.client.models.o_auth_callback_dto import OAuthCallbackDto
from immich.client.models.o_auth_config_dto import OAuthConfigDto
from immich.client.models.o_auth_token_endpoint_auth_method import (
    OAuthTokenEndpointAuthMethod,
)
from immich.client.models.ocr_config import OcrConfig
from immich.client.models.on_this_day_dto import OnThisDayDto
from immich.client.models.onboarding_dto import OnboardingDto
from immich.client.models.onboarding_response_dto import OnboardingResponseDto
from immich.client.models.partner_create_dto import PartnerCreateDto
from immich.client.models.partner_direction import PartnerDirection
from immich.client.models.partner_response_dto import PartnerResponseDto
from immich.client.models.partner_update_dto import PartnerUpdateDto
from immich.client.models.people_response import PeopleResponse
from immich.client.models.people_response_dto import PeopleResponseDto
from immich.client.models.people_update import PeopleUpdate
from immich.client.models.people_update_dto import PeopleUpdateDto
from immich.client.models.people_update_item import PeopleUpdateItem
from immich.client.models.permission import Permission
from immich.client.models.person_create_dto import PersonCreateDto
from immich.client.models.person_response_dto import PersonResponseDto
from immich.client.models.person_statistics_response_dto import (
    PersonStatisticsResponseDto,
)
from immich.client.models.person_update_dto import PersonUpdateDto
from immich.client.models.person_with_faces_response_dto import (
    PersonWithFacesResponseDto,
)
from immich.client.models.pin_code_change_dto import PinCodeChangeDto
from immich.client.models.pin_code_reset_dto import PinCodeResetDto
from immich.client.models.pin_code_setup_dto import PinCodeSetupDto
from immich.client.models.places_response_dto import PlacesResponseDto
from immich.client.models.plugin_action_response_dto import PluginActionResponseDto
from immich.client.models.plugin_context_type import PluginContextType
from immich.client.models.plugin_filter_response_dto import PluginFilterResponseDto
from immich.client.models.plugin_response_dto import PluginResponseDto
from immich.client.models.plugin_trigger_response_dto import PluginTriggerResponseDto
from immich.client.models.plugin_trigger_type import PluginTriggerType
from immich.client.models.purchase_response import PurchaseResponse
from immich.client.models.purchase_update import PurchaseUpdate
from immich.client.models.queue_command import QueueCommand
from immich.client.models.queue_command_dto import QueueCommandDto
from immich.client.models.queue_delete_dto import QueueDeleteDto
from immich.client.models.queue_job_response_dto import QueueJobResponseDto
from immich.client.models.queue_job_status import QueueJobStatus
from immich.client.models.queue_name import QueueName
from immich.client.models.queue_response_dto import QueueResponseDto
from immich.client.models.queue_response_legacy_dto import QueueResponseLegacyDto
from immich.client.models.queue_statistics_dto import QueueStatisticsDto
from immich.client.models.queue_status_legacy_dto import QueueStatusLegacyDto
from immich.client.models.queue_update_dto import QueueUpdateDto
from immich.client.models.queues_response_legacy_dto import QueuesResponseLegacyDto
from immich.client.models.random_search_dto import RandomSearchDto
from immich.client.models.ratings_response import RatingsResponse
from immich.client.models.ratings_update import RatingsUpdate
from immich.client.models.reaction_level import ReactionLevel
from immich.client.models.reaction_type import ReactionType
from immich.client.models.reverse_geocoding_state_response_dto import (
    ReverseGeocodingStateResponseDto,
)
from immich.client.models.search_album_response_dto import SearchAlbumResponseDto
from immich.client.models.search_asset_response_dto import SearchAssetResponseDto
from immich.client.models.search_explore_item import SearchExploreItem
from immich.client.models.search_explore_response_dto import SearchExploreResponseDto
from immich.client.models.search_facet_count_response_dto import (
    SearchFacetCountResponseDto,
)
from immich.client.models.search_facet_response_dto import SearchFacetResponseDto
from immich.client.models.search_response_dto import SearchResponseDto
from immich.client.models.search_statistics_response_dto import (
    SearchStatisticsResponseDto,
)
from immich.client.models.search_suggestion_type import SearchSuggestionType
from immich.client.models.server_about_response_dto import ServerAboutResponseDto
from immich.client.models.server_apk_links_dto import ServerApkLinksDto
from immich.client.models.server_config_dto import ServerConfigDto
from immich.client.models.server_features_dto import ServerFeaturesDto
from immich.client.models.server_media_types_response_dto import (
    ServerMediaTypesResponseDto,
)
from immich.client.models.server_ping_response import ServerPingResponse
from immich.client.models.server_stats_response_dto import ServerStatsResponseDto
from immich.client.models.server_storage_response_dto import ServerStorageResponseDto
from immich.client.models.server_theme_dto import ServerThemeDto
from immich.client.models.server_version_history_response_dto import (
    ServerVersionHistoryResponseDto,
)
from immich.client.models.server_version_response_dto import ServerVersionResponseDto
from immich.client.models.session_create_dto import SessionCreateDto
from immich.client.models.session_create_response_dto import SessionCreateResponseDto
from immich.client.models.session_response_dto import SessionResponseDto
from immich.client.models.session_unlock_dto import SessionUnlockDto
from immich.client.models.session_update_dto import SessionUpdateDto
from immich.client.models.set_maintenance_mode_dto import SetMaintenanceModeDto
from immich.client.models.shared_link_create_dto import SharedLinkCreateDto
from immich.client.models.shared_link_edit_dto import SharedLinkEditDto
from immich.client.models.shared_link_response_dto import SharedLinkResponseDto
from immich.client.models.shared_link_type import SharedLinkType
from immich.client.models.shared_links_response import SharedLinksResponse
from immich.client.models.shared_links_update import SharedLinksUpdate
from immich.client.models.sign_up_dto import SignUpDto
from immich.client.models.smart_search_dto import SmartSearchDto
from immich.client.models.source_type import SourceType
from immich.client.models.stack_create_dto import StackCreateDto
from immich.client.models.stack_response_dto import StackResponseDto
from immich.client.models.stack_update_dto import StackUpdateDto
from immich.client.models.statistics_search_dto import StatisticsSearchDto
from immich.client.models.sync_ack_delete_dto import SyncAckDeleteDto
from immich.client.models.sync_ack_dto import SyncAckDto
from immich.client.models.sync_ack_set_dto import SyncAckSetDto
from immich.client.models.sync_album_delete_v1 import SyncAlbumDeleteV1
from immich.client.models.sync_album_to_asset_delete_v1 import SyncAlbumToAssetDeleteV1
from immich.client.models.sync_album_to_asset_v1 import SyncAlbumToAssetV1
from immich.client.models.sync_album_user_delete_v1 import SyncAlbumUserDeleteV1
from immich.client.models.sync_album_user_v1 import SyncAlbumUserV1
from immich.client.models.sync_album_v1 import SyncAlbumV1
from immich.client.models.sync_asset_delete_v1 import SyncAssetDeleteV1
from immich.client.models.sync_asset_exif_v1 import SyncAssetExifV1
from immich.client.models.sync_asset_face_delete_v1 import SyncAssetFaceDeleteV1
from immich.client.models.sync_asset_face_v1 import SyncAssetFaceV1
from immich.client.models.sync_asset_metadata_delete_v1 import SyncAssetMetadataDeleteV1
from immich.client.models.sync_asset_metadata_v1 import SyncAssetMetadataV1
from immich.client.models.sync_asset_v1 import SyncAssetV1
from immich.client.models.sync_auth_user_v1 import SyncAuthUserV1
from immich.client.models.sync_entity_type import SyncEntityType
from immich.client.models.sync_memory_asset_delete_v1 import SyncMemoryAssetDeleteV1
from immich.client.models.sync_memory_asset_v1 import SyncMemoryAssetV1
from immich.client.models.sync_memory_delete_v1 import SyncMemoryDeleteV1
from immich.client.models.sync_memory_v1 import SyncMemoryV1
from immich.client.models.sync_partner_delete_v1 import SyncPartnerDeleteV1
from immich.client.models.sync_partner_v1 import SyncPartnerV1
from immich.client.models.sync_person_delete_v1 import SyncPersonDeleteV1
from immich.client.models.sync_person_v1 import SyncPersonV1
from immich.client.models.sync_request_type import SyncRequestType
from immich.client.models.sync_stack_delete_v1 import SyncStackDeleteV1
from immich.client.models.sync_stack_v1 import SyncStackV1
from immich.client.models.sync_stream_dto import SyncStreamDto
from immich.client.models.sync_user_delete_v1 import SyncUserDeleteV1
from immich.client.models.sync_user_metadata_delete_v1 import SyncUserMetadataDeleteV1
from immich.client.models.sync_user_metadata_v1 import SyncUserMetadataV1
from immich.client.models.sync_user_v1 import SyncUserV1
from immich.client.models.system_config_backups_dto import SystemConfigBackupsDto
from immich.client.models.system_config_dto import SystemConfigDto
from immich.client.models.system_config_f_fmpeg_dto import SystemConfigFFmpegDto
from immich.client.models.system_config_faces_dto import SystemConfigFacesDto
from immich.client.models.system_config_generated_fullsize_image_dto import (
    SystemConfigGeneratedFullsizeImageDto,
)
from immich.client.models.system_config_generated_image_dto import (
    SystemConfigGeneratedImageDto,
)
from immich.client.models.system_config_image_dto import SystemConfigImageDto
from immich.client.models.system_config_job_dto import SystemConfigJobDto
from immich.client.models.system_config_library_dto import SystemConfigLibraryDto
from immich.client.models.system_config_library_scan_dto import (
    SystemConfigLibraryScanDto,
)
from immich.client.models.system_config_library_watch_dto import (
    SystemConfigLibraryWatchDto,
)
from immich.client.models.system_config_logging_dto import SystemConfigLoggingDto
from immich.client.models.system_config_machine_learning_dto import (
    SystemConfigMachineLearningDto,
)
from immich.client.models.system_config_map_dto import SystemConfigMapDto
from immich.client.models.system_config_metadata_dto import SystemConfigMetadataDto
from immich.client.models.system_config_new_version_check_dto import (
    SystemConfigNewVersionCheckDto,
)
from immich.client.models.system_config_nightly_tasks_dto import (
    SystemConfigNightlyTasksDto,
)
from immich.client.models.system_config_notifications_dto import (
    SystemConfigNotificationsDto,
)
from immich.client.models.system_config_o_auth_dto import SystemConfigOAuthDto
from immich.client.models.system_config_password_login_dto import (
    SystemConfigPasswordLoginDto,
)
from immich.client.models.system_config_reverse_geocoding_dto import (
    SystemConfigReverseGeocodingDto,
)
from immich.client.models.system_config_server_dto import SystemConfigServerDto
from immich.client.models.system_config_smtp_dto import SystemConfigSmtpDto
from immich.client.models.system_config_smtp_transport_dto import (
    SystemConfigSmtpTransportDto,
)
from immich.client.models.system_config_storage_template_dto import (
    SystemConfigStorageTemplateDto,
)
from immich.client.models.system_config_template_emails_dto import (
    SystemConfigTemplateEmailsDto,
)
from immich.client.models.system_config_template_storage_option_dto import (
    SystemConfigTemplateStorageOptionDto,
)
from immich.client.models.system_config_templates_dto import SystemConfigTemplatesDto
from immich.client.models.system_config_theme_dto import SystemConfigThemeDto
from immich.client.models.system_config_trash_dto import SystemConfigTrashDto
from immich.client.models.system_config_user_dto import SystemConfigUserDto
from immich.client.models.tag_bulk_assets_dto import TagBulkAssetsDto
from immich.client.models.tag_bulk_assets_response_dto import TagBulkAssetsResponseDto
from immich.client.models.tag_create_dto import TagCreateDto
from immich.client.models.tag_response_dto import TagResponseDto
from immich.client.models.tag_update_dto import TagUpdateDto
from immich.client.models.tag_upsert_dto import TagUpsertDto
from immich.client.models.tags_response import TagsResponse
from immich.client.models.tags_update import TagsUpdate
from immich.client.models.template_dto import TemplateDto
from immich.client.models.template_response_dto import TemplateResponseDto
from immich.client.models.test_email_response_dto import TestEmailResponseDto
from immich.client.models.time_bucket_asset_response_dto import (
    TimeBucketAssetResponseDto,
)
from immich.client.models.time_buckets_response_dto import TimeBucketsResponseDto
from immich.client.models.tone_mapping import ToneMapping
from immich.client.models.transcode_hw_accel import TranscodeHWAccel
from immich.client.models.transcode_policy import TranscodePolicy
from immich.client.models.trash_response_dto import TrashResponseDto
from immich.client.models.update_album_dto import UpdateAlbumDto
from immich.client.models.update_album_user_dto import UpdateAlbumUserDto
from immich.client.models.update_asset_dto import UpdateAssetDto
from immich.client.models.update_library_dto import UpdateLibraryDto
from immich.client.models.usage_by_user_dto import UsageByUserDto
from immich.client.models.user_admin_create_dto import UserAdminCreateDto
from immich.client.models.user_admin_delete_dto import UserAdminDeleteDto
from immich.client.models.user_admin_response_dto import UserAdminResponseDto
from immich.client.models.user_admin_update_dto import UserAdminUpdateDto
from immich.client.models.user_avatar_color import UserAvatarColor
from immich.client.models.user_license import UserLicense
from immich.client.models.user_metadata_key import UserMetadataKey
from immich.client.models.user_preferences_response_dto import (
    UserPreferencesResponseDto,
)
from immich.client.models.user_preferences_update_dto import UserPreferencesUpdateDto
from immich.client.models.user_response_dto import UserResponseDto
from immich.client.models.user_status import UserStatus
from immich.client.models.user_update_me_dto import UserUpdateMeDto
from immich.client.models.validate_access_token_response_dto import (
    ValidateAccessTokenResponseDto,
)
from immich.client.models.validate_library_dto import ValidateLibraryDto
from immich.client.models.validate_library_import_path_response_dto import (
    ValidateLibraryImportPathResponseDto,
)
from immich.client.models.validate_library_response_dto import (
    ValidateLibraryResponseDto,
)
from immich.client.models.version_check_state_response_dto import (
    VersionCheckStateResponseDto,
)
from immich.client.models.video_codec import VideoCodec
from immich.client.models.video_container import VideoContainer
from immich.client.models.workflow_action_item_dto import WorkflowActionItemDto
from immich.client.models.workflow_action_response_dto import WorkflowActionResponseDto
from immich.client.models.workflow_create_dto import WorkflowCreateDto
from immich.client.models.workflow_filter_item_dto import WorkflowFilterItemDto
from immich.client.models.workflow_filter_response_dto import WorkflowFilterResponseDto
from immich.client.models.workflow_response_dto import WorkflowResponseDto
from immich.client.models.workflow_update_dto import WorkflowUpdateDto



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from uuid import UUID
from immich.client.models.asset_visibility import AssetVisibility
from typing import Set
from typing_extensions import Self


class UpdateAssetDto(BaseModel):
    """
    UpdateAssetDto
    """  # noqa: E501

    date_time_original: Optional[StrictStr] = Field(
        default=None, alias="dateTimeOriginal"
    )
    description: Optional[StrictStr] = None
    is_favorite: Optional[StrictBool] = Field(default=None, alias="isFavorite")
    latitude: Optional[Union[StrictFloat, StrictInt]] = None
    live_photo_video_id: Optional[UUID] = Field(default=None, alias="livePhotoVideoId")
    longitude: Optional[Union[StrictFloat, StrictInt]] = None
    rating: Optional[
        Union[
            Annotated[float, Field(le=5, strict=True, ge=-1)],
            Annotated[int, Field(le=5, strict=True, ge=-1)],
        ]
    ] = None
    visibility: Optional[AssetVisibility] = None
    __properties: ClassVar[List[str]] = [
        "dateTimeOriginal",
        "description",
        "isFavorite",
        "latitude",
        "livePhotoVideoId",
        "longitude",
        "rating",
        "visibility",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UpdateAssetDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if live_photo_video_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.live_photo_video_id is None
            and "live_photo_video_id" in self.model_fields_set
        ):
            _dict["livePhotoVideoId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UpdateAssetDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "dateTimeOriginal": obj.get("dateTimeOriginal"),
                "description": obj.get("description"),
                "isFavorite": obj.get("isFavorite"),
                "latitude": obj.get("latitude"),
                "livePhotoVideoId": obj.get("livePhotoVideoId"),
                "longitude": obj.get("longitude"),
                "rating": obj.get("rating"),
                "visibility": obj.get("visibility"),
            }
        )
        return _obj



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Permission(str, Enum):
    """
    Permission
    """

    """
    allowed enum values
    """
    ALL = "all"
    ACTIVITY_DOT_CREATE = "activity.create"
    ACTIVITY_DOT_READ = "activity.read"
    ACTIVITY_DOT_UPDATE = "activity.update"
    ACTIVITY_DOT_DELETE = "activity.delete"
    ACTIVITY_DOT_STATISTICS = "activity.statistics"
    API_KEY_DOT_CREATE = "apiKey.create"
    API_KEY_DOT_READ = "apiKey.read"
    API_KEY_DOT_UPDATE = "apiKey.update"
    API_KEY_DOT_DELETE = "apiKey.delete"
    ASSET_DOT_READ = "asset.read"
    ASSET_DOT_UPDATE = "asset.update"
    ASSET_DOT_DELETE = "asset.delete"
    ASSET_DOT_STATISTICS = "asset.statistics"
    ASSET_DOT_SHARE = "asset.share"
    ASSET_DOT_VIEW = "asset.view"
    ASSET_DOT_DOWNLOAD = "asset.download"
    ASSET_DOT_UPLOAD = "asset.upload"
    ASSET_DOT_REPLACE = "asset.replace"
    ASSET_DOT_COPY = "asset.copy"
    ALBUM_DOT_CREATE = "album.create"
    ALBUM_DOT_READ = "album.read"
    ALBUM_DOT_UPDATE = "album.update"
    ALBUM_DOT_DELETE = "album.delete"
    ALBUM_DOT_STATISTICS = "album.statistics"
    ALBUM_DOT_SHARE = "album.share"
    ALBUM_DOT_DOWNLOAD = "album.download"
    ALBUM_ASSET_DOT_CREATE = "albumAsset.create"
    ALBUM_ASSET_DOT_DELETE = "albumAsset.delete"
    ALBUM_USER_DOT_CREATE = "albumUser.create"
    ALBUM_USER_DOT_UPDATE = "albumUser.update"
    ALBUM_USER_DOT_DELETE = "albumUser.delete"
    AUTH_DOT_CHANGE_PASSWORD = "auth.changePassword"
    AUTH_DEVICE_DOT_DELETE = "authDevice.delete"
    ARCHIVE_DOT_READ = "archive.read"
    DUPLICATE_DOT_READ = "duplicate.read"
    DUPLICATE_DOT_DELETE = "duplicate.delete"
    FACE_DOT_CREATE = "face.create"
    FACE_DOT_READ = "face.read"
    FACE_DOT_UPDATE = "face.update"
    FACE_DOT_DELETE = "face.delete"
    JOB_DOT_CREATE = "job.create"
    JOB_DOT_READ = "job.read"
    LIBRARY_DOT_CREATE = "library.create"
    LIBRARY_DOT_READ = "library.read"
    LIBRARY_DOT_UPDATE = "library.update"
    LIBRARY_DOT_DELETE = "library.delete"
    LIBRARY_DOT_STATISTICS = "library.statistics"
    TIMELINE_DOT_READ = "timeline.read"
    TIMELINE_DOT_DOWNLOAD = "timeline.download"
    MAINTENANCE = "maintenance"
    MEMORY_DOT_CREATE = "memory.create"
    MEMORY_DOT_READ = "memory.read"
    MEMORY_DOT_UPDATE = "memory.update"
    MEMORY_DOT_DELETE = "memory.delete"
    MEMORY_DOT_STATISTICS = "memory.statistics"
    MEMORY_ASSET_DOT_CREATE = "memoryAsset.create"
    MEMORY_ASSET_DOT_DELETE = "memoryAsset.delete"
    NOTIFICATION_DOT_CREATE = "notification.create"
    NOTIFICATION_DOT_READ = "notification.read"
    NOTIFICATION_DOT_UPDATE = "notification.update"
    NOTIFICATION_DOT_DELETE = "notification.delete"
    PARTNER_DOT_CREATE = "partner.create"
    PARTNER_DOT_READ = "partner.read"
    PARTNER_DOT_UPDATE = "partner.update"
    PARTNER_DOT_DELETE = "partner.delete"
    PERSON_DOT_CREATE = "person.create"
    PERSON_DOT_READ = "person.read"
    PERSON_DOT_UPDATE = "person.update"
    PERSON_DOT_DELETE = "person.delete"
    PERSON_DOT_STATISTICS = "person.statistics"
    PERSON_DOT_MERGE = "person.merge"
    PERSON_DOT_REASSIGN = "person.reassign"
    PIN_CODE_DOT_CREATE = "pinCode.create"
    PIN_CODE_DOT_UPDATE = "pinCode.update"
    PIN_CODE_DOT_DELETE = "pinCode.delete"
    PLUGIN_DOT_CREATE = "plugin.create"
    PLUGIN_DOT_READ = "plugin.read"
    PLUGIN_DOT_UPDATE = "plugin.update"
    PLUGIN_DOT_DELETE = "plugin.delete"
    SERVER_DOT_ABOUT = "server.about"
    SERVER_DOT_APK_LINKS = "server.apkLinks"
    SERVER_DOT_STORAGE = "server.storage"
    SERVER_DOT_STATISTICS = "server.statistics"
    SERVER_DOT_VERSION_CHECK = "server.versionCheck"
    SERVER_LICENSE_DOT_READ = "serverLicense.read"
    SERVER_LICENSE_DOT_UPDATE = "serverLicense.update"
    SERVER_LICENSE_DOT_DELETE = "serverLicense.delete"
    SESSION_DOT_CREATE = "session.create"
    SESSION_DOT_READ = "session.read"
    SESSION_DOT_UPDATE = "session.update"
    SESSION_DOT_DELETE = "session.delete"
    SESSION_DOT_LOCK = "session.lock"
    SHARED_LINK_DOT_CREATE = "sharedLink.create"
    SHARED_LINK_DOT_READ = "sharedLink.read"
    SHARED_LINK_DOT_UPDATE = "sharedLink.update"
    SHARED_LINK_DOT_DELETE = "sharedLink.delete"
    STACK_DOT_CREATE = "stack.create"
    STACK_DOT_READ = "stack.read"
    STACK_DOT_UPDATE = "stack.update"
    STACK_DOT_DELETE = "stack.delete"
    SYNC_DOT_STREAM = "sync.stream"
    SYNC_CHECKPOINT_DOT_READ = "syncCheckpoint.read"
    SYNC_CHECKPOINT_DOT_UPDATE = "syncCheckpoint.update"
    SYNC_CHECKPOINT_DOT_DELETE = "syncCheckpoint.delete"
    SYSTEM_CONFIG_DOT_READ = "systemConfig.read"
    SYSTEM_CONFIG_DOT_UPDATE = "systemConfig.update"
    SYSTEM_METADATA_DOT_READ = "systemMetadata.read"
    SYSTEM_METADATA_DOT_UPDATE = "systemMetadata.update"
    TAG_DOT_CREATE = "tag.create"
    TAG_DOT_READ = "tag.read"
    TAG_DOT_UPDATE = "tag.update"
    TAG_DOT_DELETE = "tag.delete"
    TAG_DOT_ASSET = "tag.asset"
    USER_DOT_READ = "user.read"
    USER_DOT_UPDATE = "user.update"
    USER_LICENSE_DOT_CREATE = "userLicense.create"
    USER_LICENSE_DOT_READ = "userLicense.read"
    USER_LICENSE_DOT_UPDATE = "userLicense.update"
    USER_LICENSE_DOT_DELETE = "userLicense.delete"
    USER_ONBOARDING_DOT_READ = "userOnboarding.read"
    USER_ONBOARDING_DOT_UPDATE = "userOnboarding.update"
    USER_ONBOARDING_DOT_DELETE = "userOnboarding.delete"
    USER_PREFERENCE_DOT_READ = "userPreference.read"
    USER_PREFERENCE_DOT_UPDATE = "userPreference.update"
    USER_PROFILE_IMAGE_DOT_CREATE = "userProfileImage.create"
    USER_PROFILE_IMAGE_DOT_READ = "userProfileImage.read"
    USER_PROFILE_IMAGE_DOT_UPDATE = "userProfileImage.update"
    USER_PROFILE_IMAGE_DOT_DELETE = "userProfileImage.delete"
    QUEUE_DOT_READ = "queue.read"
    QUEUE_DOT_UPDATE = "queue.update"
    QUEUE_JOB_DOT_CREATE = "queueJob.create"
    QUEUE_JOB_DOT_READ = "queueJob.read"
    QUEUE_JOB_DOT_UPDATE = "queueJob.update"
    QUEUE_JOB_DOT_DELETE = "queueJob.delete"
    WORKFLOW_DOT_CREATE = "workflow.create"
    WORKFLOW_DOT_READ = "workflow.read"
    WORKFLOW_DOT_UPDATE = "workflow.update"
    WORKFLOW_DOT_DELETE = "workflow.delete"
    ADMIN_USER_DOT_CREATE = "adminUser.create"
    ADMIN_USER_DOT_READ = "adminUser.read"
    ADMIN_USER_DOT_UPDATE = "adminUser.update"
    ADMIN_USER_DOT_DELETE = "adminUser.delete"
    ADMIN_SESSION_DOT_READ = "adminSession.read"
    ADMIN_AUTH_DOT_UNLINK_ALL = "adminAuth.unlinkAll"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Permission from a JSON string"""
        return cls(json.loads(json_str))
